@@ -1,6 +1,4 @@
 from .pysed import main
-from .pysed import replace
-from .pysed import append
 
 from .pysed import __version__
 from .pysed import __license__
